@@ -5,12 +5,6 @@ from smartify import E
 from .vocab import Vocab
 
 
-@E.register(id_processor=E.idp_cls_prefix())
-class VocabDepotError:
-    ConflictName = E('Conflict name: {}')
-    NotFound = E('Not found vocab {}')
-
-
 class VocabDepot:
     def __init__(self):
         self.depot = {}  # type: Dict[str, Vocab]
@@ -29,13 +23,13 @@ class VocabDepot:
 
         assert vocab.name is not None
         if vocab.name in self.depot and self.depot[vocab.name] != vocab:
-            raise VocabDepotError.ConflictName(vocab.name)
+            raise f'Conflict name: {vocab.name}'
         self.depot[vocab.name] = vocab
 
     def get_vocab(self, name) -> Vocab:
         if name in self.depot:
             return self.depot[name]
-        raise VocabDepotError.NotFound(name)
+        raise f'Not found vocab {name}'
 
     def __call__(self, name) -> Vocab:
         return self.get_vocab(name)
